@@ -760,7 +760,7 @@ void MainWindow::setupTitlebar()
     _titlebar->move(1, 1);
 #endif
     _titlebar->setFixedHeight(30);
-    _titlebar->layout()->setContentsMargins(0, 0, 6, 0);
+    _titlebar->layout()->setContentsMargins(0, 0, 0, 0);
     _titlebar->setFocusPolicy(Qt::NoFocus);
     if (!CompositingManager::get().composited()) {
         _titlebar->setAttribute(Qt::WA_NativeWindow);
@@ -913,26 +913,16 @@ void MainWindow::onWindowStateChanged()
 
 void MainWindow::handleHelpAction()
 {
-    QString appid = qApp->applicationName();
-#ifdef DTK_DMAN_PORTAL
-    if (!qgetenv("FLATPAK_APPID").isEmpty()) {
-        appid = qgetenv("FLATPAK_APPID");
-    }
-
-    QDBusInterface dmanInterface("com.deepin.dman",
-                                 "/com/deepin/dman",
-                                 "com.deepin.dman");
-    if (dmanInterface.isValid()) {
-        auto reply = dmanInterface.call("ShowManual", appid);
-        if (dmanInterface.lastError().isValid()) {
-            qCritical() << "failed call ShowManual" << appid << dmanInterface.lastError();
+    class _DApplication : public DApplication
+    {
+    public:
+        inline void showHelp() {
+            DApplication::handleHelpAction();
         }
-    } else {
-        qCritical() << "can not create dman dbus interface";
-    }
-#else
-    QProcess::startDetached("dman", QStringList() << appid);
-#endif
+    };
+
+    DApplication *dapp = qApp;
+    reinterpret_cast<_DApplication*>(dapp)->_DApplication::showHelp();
 }
 
 #ifdef USE_DXCB
